==> hawk-soar-app-cisco-meraki-hostlookup-1.0.0.tgz: package/index.js <==

const fs = require('fs')
const path = __dirname + '/package.json'
const axios = require('axios')

let data = fs.readFileSync(path, { encoding: 'utf8', flag: 'r' })
let pkginfo = JSON.parse(data)

function sleep(ms) {
  return new Promise((resolve) => {
    setTimeout(resolve, ms);
  });
}

module.exports = {
    ...pkginfo,
    handler: function(db, socket, redisClient, request, message, exported) {
        // socket handler
      console.log('Inside hawk chatgpt handler')
      console.log(socket)

      let lmessage
      let r
      let data

      if (!('route' in message)) {
        lmessage = message
        lmessage.status = false
        lmessage.code = 404
        lmessage.details = 'No cmd field has been specified, unable to continue.'
        socket.send(JSON.stringify(lmessage))
        return
      }

      if (request.session.userProfile.isAdmin == false && request.session.userProfile.isSOC == false) {
        lmessage = message
        lmessage.status = false
        lmessage.code = 404
        lmessage.details = 'User has invalid permissions for access; must have SOC or Admin privileges.'
        socket.send(JSON.stringify(lmessage))
        return
      }

      const cmd = camelize(message.route)
      console.log(cmd)

      switch (cmd) {

        case 'networks':
          if (!('data' in message)) {
            lmessage = message
            lmessage.status = false
            lmessage.code = 404
            lmessage.details = `No data found in message: ${message.route}`
            socket.send(JSON.stringify(lmessage))
            return
          }
          r = message
          module.exports.networks(db, request.session, message.data, exported).then((x) => {
            r.data = x
            r.status = true
            r.code = 200
            console.log("Sending back results")
            console.log(x)
            r.details = `Successfully fetched results.`
            socket.send(JSON.stringify(r))
          })
            .catch((e) => {
              lmessage = message
              lmessage.status = false
              lmessage.code = 500
              lmessage.details = e.toString()
              socket.send(JSON.stringify(lmessage))
            })
          break

        case 'search':
          if (!('data' in message)) {
            lmessage = message
            lmessage.status = false
            lmessage.code = 404
            lmessage.details = `No data found in message: ${message.route}`
            socket.send(JSON.stringify(lmessage))
            return
          }
          r = message
          module.exports.search(db, request.session, message.data, exported).then((x) => {
            r.data = x
            r.status = true
            r.code = 200
            console.log("Sending back results")
            console.log(x)
            r.details = `Successfully fetched results.`
            socket.send(JSON.stringify(r))
          })
            .catch((e) => {
              lmessage = message
              lmessage.status = false
              lmessage.code = 500
              lmessage.details = e.toString()
              socket.send(JSON.stringify(lmessage))
            })
          break
        default:
          lmessage = message
          lmessage.status = false
          lmessage.code = 404
          lmessage.details = `No known route found matching ${message.route}`
          socket.send(JSON.stringify(lmessage))
          break
      }

    },
    registerRoutes: function(app) {
    },

};

const camelize = function (str) {
  return str.replace(/(?:^\w|[A-Z]|\b\w|\s+)/g, (match, index) => {
    if (+match === 0) return '' // or if (/\s+/.test(match)) for white spaces
    return index === 0 ? match.toLowerCase() : match.toUpperCase()
  })
}

module.exports.networks = function(db, session, record, exported) {
  // fetch the given credentials from vault, send err msg on failure
  // on success make call for categories and severities.

  console.log(record)
  console.log('Fetching credential')
  console.log(exported)
  return exported['credentials.getCredential'](record.group_id, record.credential_id, record.token, db, session).then((x) => {
    console.log("Caugth credential response from token")
    console.log(x.data)
    let xd = x.data
    console.log(JSON.stringify(x.data))
    if ('data' in xd && 'data' in xd.data && xd.data.data.tokenSecret) {
      const tokenSecret = xd.data.data.tokenSecret
      // fetch action info by id
      return exported['actions.getEntry'](db, session, record.action_id).then((x) => {
         console.log("Caught action entry")
         console.log(x)
         if (x.length == 0) throw new Error("No action vendor record found.")
         const escData = x[0]

         // call the right api

         return axios.get(`https://api.meraki.com/api/v1/organizations/`, {
             headers: {
               'Authorization': 'Bearer ' + tokenSecret
             }, 
         })
         .then(response => {
             console.log('Organizations:', response.data);
             let orgId = response.data
             return axios.get(`https://api.meraki.com/api/v1/organizations/${orgId}/networks`, {
               headers: {
                 'Authorization': 'Bearer ' + tokenSecret
               }, 
             })
             .then(response2 => {
               console.log(response2.data)
               return response2.data
             })
         })
         .catch(error => {
             console.log("meraki fetch failed")
             console.log( error.response.data)
             console.error('Error:', error.response.data)
             throw new Error(error.response.data);
         });

      })
    } else
      throw new Error("Credential token failed to match, unable to fetch credential secret.")
  })
}


module.exports.search = function(db, session, record, exported) {
  // fetch the given credentials from vault, send err msg on failure
  // on success make call for categories and severities.

  console.log(record)
  console.log('Fetching credential')
  console.log(exported)
  return exported['credentials.getCredential'](record.group_id, record.credential_id, record.token, db, session).then((x) => {
    console.log("Caugth credential response from token")
    console.log(x.data)
    let xd = x.data
    console.log(JSON.stringify(x.data))
    if ('data' in xd && 'data' in xd.data && xd.data.data.tokenSecret) {
      const tokenSecret = xd.data.data.tokenSecret
      // fetch action info by id
      return exported['actions.getEntry'](db, session, record.action_id).then((x) => {
         console.log("Caught action entry")
         console.log(x)
         if (x.length == 0) throw new Error("No action vendor record found.")
         const escData = x[0]

         // call the right api

         return axios.get(`https://api.meraki.com/api/v1/organizations/${record.body}`, {
             headers: {
               'Authorization': 'Bearer ' + tokenSecret
             }, 
         })
         .then(response => {
             console.log('Analysis report:', response.data);
             // building our response based on the data found
             return response.data
         })
         .catch(error => {
             console.log("virustotal fetch failed")
             console.log( error.response.data.error.message)
             console.error('Error:', error.response ? error.response.data.error : error.message);
             throw new Error(error.response.data.error.message);
         });

      })
    } else
      throw new Error("Credential token failed to match, unable to fetch credential secret.")
  })
}

==> hawk-soar-app-cisco-meraki-hostlookup-1.0.1.tgz: package/index.js <==

const fs = require('fs')
const path = __dirname + '/package.json'
const axios = require('axios')

let data = fs.readFileSync(path, { encoding: 'utf8', flag: 'r' })
let pkginfo = JSON.parse(data)

function sleep(ms) {
  return new Promise((resolve) => {
    setTimeout(resolve, ms);
  });
}

module.exports = {
    ...pkginfo,
    handler: function(db, socket, redisClient, request, message, exported) {
        // socket handler
      console.log('Inside hawk chatgpt handler')
      console.log(socket)

      let lmessage
      let r
      let data

      if (!('route' in message)) {
        lmessage = message
        lmessage.status = false
        lmessage.code = 404
        lmessage.details = 'No cmd field has been specified, unable to continue.'
        socket.send(JSON.stringify(lmessage))
        return
      }

      if (request.session.userProfile.isAdmin == false && request.session.userProfile.isSOC == false) {
        lmessage = message
        lmessage.status = false
        lmessage.code = 404
        lmessage.details = 'User has invalid permissions for access; must have SOC or Admin privileges.'
        socket.send(JSON.stringify(lmessage))
        return
      }

      const cmd = camelize(message.route)
      console.log(cmd)

      switch (cmd) {

        case 'networks':
          if (!('data' in message)) {
            lmessage = message
            lmessage.status = false
            lmessage.code = 404
            lmessage.details = `No data found in message: ${message.route}`
            socket.send(JSON.stringify(lmessage))
            return
          }
          r = message
          module.exports.networks(db, request.session, message.data, exported).then((x) => {
            r.data = x
            r.status = true
            r.code = 200
            console.log("Sending back results")
            console.log(x)
            r.details = `Successfully fetched results.`
            socket.send(JSON.stringify(r))
          })
            .catch((e) => {
              lmessage = message
              lmessage.status = false
              lmessage.code = 500
              lmessage.details = e.toString()
              socket.send(JSON.stringify(lmessage))
            })
          break

        case 'search':
          if (!('data' in message)) {
            lmessage = message
            lmessage.status = false
            lmessage.code = 404
            lmessage.details = `No data found in message: ${message.route}`
            socket.send(JSON.stringify(lmessage))
            return
          }
          r = message
          module.exports.search(db, request.session, message.data, exported).then((x) => {
            r.data = x
            r.status = true
            r.code = 200
            console.log("Sending back results")
            console.log(x)
            r.details = `Successfully fetched results.`
            socket.send(JSON.stringify(r))
          })
            .catch((e) => {
              lmessage = message
              lmessage.status = false
              lmessage.code = 500
              lmessage.details = e.toString()
              socket.send(JSON.stringify(lmessage))
            })
          break
        default:
          lmessage = message
          lmessage.status = false
          lmessage.code = 404
          lmessage.details = `No known route found matching ${message.route}`
          socket.send(JSON.stringify(lmessage))
          break
      }

    },
    registerRoutes: function(app) {
    },

};

const camelize = function (str) {
  return str.replace(/(?:^\w|[A-Z]|\b\w|\s+)/g, (match, index) => {
    if (+match === 0) return '' // or if (/\s+/.test(match)) for white spaces
    return index === 0 ? match.toLowerCase() : match.toUpperCase()
  })
}

module.exports.networks = function(db, session, record, exported) {
  // fetch the given credentials from vault, send err msg on failure
  // on success make call for categories and severities.

  console.log(record)
  console.log('Fetching credential')
  console.log(exported)
  return exported['credentials.getCredential'](record.group_id, record.credential_id, record.token, db, session).then((x) => {
    console.log("Caugth credential response from token")
    console.log(x.data)
    let xd = x.data
    console.log(JSON.stringify(x.data))
    if ('data' in xd && 'data' in xd.data && xd.data.data.tokenSecret) {
      const tokenSecret = xd.data.data.tokenSecret
      // fetch action info by id
      return exported['actions.getEntry'](db, session, record.action_id).then((x) => {
         console.log("Caught action entry")
         console.log(x)
         if (x.length == 0) throw new Error("No action vendor record found.")
         const escData = x[0]

         // call the right api

         if(!record.organization_id) { // get default organization if not specified
             console.log('No organization id provided')
           
             return axios.get(`https://api.meraki.com/api/v1/organizations/`, {
               headers: {
                 'Authorization': 'Bearer ' + tokenSecret
               }, 
           })
           .then(response => {
               console.log('Organizations:', response.data);
               let orgId = response.data[0]
               console.log(orgId)
               console.log(orgId.id)
               const url = `https://api.meraki.com/api/v1/organizations/${orgId.id}/networks`
               console.log(url)
               return axios.get(url, {
                 headers: {
                   'Authorization': 'Bearer ' + tokenSecret
                 }, 
               })
               .then(response2 => {
                 console.log(response2.data)
                 let ret = { organizations: response.data, networks: response2.data }
                 return ret
               })
           })
           .catch(error => {
               console.log("meraki fetch failed")
               console.log( error.response.data)
               console.error('Error:', error.response.data)
               throw new Error(error.response.data);
           });

        } else { // org id provided
           const url = `https://api.meraki.com/api/v1/organizations/${record.organization_id}/networks`
           console.log(url)
           return axios.get(url, {
             headers: {
               'Authorization': 'Bearer ' + tokenSecret
             }, 
           })
           .then(response2 => {
             let ret = { organizations: null, networks: response2.data }
             return response2.data
           })
           .catch(error => {
               console.log("meraki fetch failed")
               console.log( error.response.data)
               console.error('Error:', error.response.data)
               throw new Error(error.response.data);
           })
        }

      })
    } else
      throw new Error("Credential token failed to match, unable to fetch credential secret.")
  })
}


module.exports.search = function(db, session, record, exported) {
  // fetch the given credentials from vault, send err msg on failure
  // on success make call for categories and severities.

  console.log(record)
  console.log('Fetching credential')
  console.log(exported)
  return exported['credentials.getCredential'](record.group_id, record.credential_id, record.token, db, session).then((x) => {
    console.log("Caugth credential response from token")
    console.log(x.data)
    let xd = x.data
    console.log(JSON.stringify(x.data))
    if ('data' in xd && 'data' in xd.data && xd.data.data.tokenSecret) {
      const tokenSecret = xd.data.data.tokenSecret
      // fetch action info by id
      return exported['actions.getEntry'](db, session, record.action_id).then((x) => {
         console.log("Caught action entry")
         console.log(x)
         if (x.length == 0) throw new Error("No action vendor record found.")
         const escData = x[0]

         // call the right api

         return axios.get(`https://api.meraki.com/api/v1/networks/${record.network_id}/clients?timespan=86400`, {
             headers: {
               'Authorization': 'Bearer ' + tokenSecret
             }, 
         })
         .then(response => {
             console.log('Analysis report:', response.data);
             // building our response based on the data found
             
             return response.data
         })
         .catch(error => {
             console.log("virustotal fetch failed")
             console.log( error.response.data.error.message)
             console.error('Error:', error.response ? error.response.data.error : error.message);
             throw new Error(error.response.data.error.message);
         });

      })
    } else
      throw new Error("Credential token failed to match, unable to fetch credential secret.")
  })
}
